@@ -1,4 +1,23 @@
 # -*- coding: utf-8 -*-
+
+# Copyright © 2012 Gerd Kohlberger <lowfi@chello.at>
+# Copyright © 2011-2014 marmuta <marmvta@gmail.com>
+#
+# This file is part of Onboard.
+#
+# Onboard is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Onboard is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+
 """ Classes for recursive layout definition """
 
 from __future__ import division, print_function, unicode_literals
@@ -333,6 +352,10 @@ class LayoutItem(TreeItem):
     # group string of the item, label size group for keys
     group = None
 
+    # take this item out of the size group when updating the layout.
+    # Instead chose the best label size for this item alone.
+    ignore_group = None
+
     # name of the layer the item is to be shown on, None for all layers
     layer_id = None
 
